/**
 * Logger for search.
 * @constructor SrchLogger
 * @returns A logger instance.
 */

'use strict'

const colorprint = require('colorprint')
const textconv = require('textconv')
const { colors } = colorprint

/** @lends SrchLogger */
module.exports = colorprint.define(
  /** @lends SrchLogger.prototype */
  {
    logSearchStart () {
      const s = this
      s.info('Searching modules...')
    },
    logSearchDone () {
      const s = this
      s.info('...search done!')
    },
    logSearched (serched, terms) {
      const s = this
      s.debug('')
      if (terms.length > 0) {
        s.debug('  Terms: %s', colors.blue.italic(terms.join(', ')))
      }
      s.debug('  Searched modules:')
      s.debug('')
      let NAME_MIN_LENGTH = 24
      serched
        .filter((searched) => searched.hit)
        .sort((a, b) => String(a.name).localeCompare(String(b.name)))
        .forEach((serched) => {
          let { hitTerm, description } = serched
          let name = textconv.pad(serched.name, NAME_MIN_LENGTH)
          if (hitTerm) {
            name = s._highlight(name, hitTerm)
            description = s._highlight(description, hitTerm)
          }
          s.debug('    %s%s',
            colors.black.bold(name),
            colors.blackBright(description)
          )
        })
      s.debug('')
      s.debug('')
    },
    _highlight (text, keyword) {
      return text &&
        text.replace(new RegExp(keyword, 'g'), (keyword) =>
          colors.blue.bold(keyword)
        )
    }
  }
)
